@@ -1,5 +1,5 @@
 package List::DoubleLinked;
-$List::DoubleLinked::VERSION = '0.004';
+$List::DoubleLinked::VERSION = '0.005';
 use strict;
 use warnings FATAL => 'all';
 
@@ -67,7 +67,7 @@ sub shift {
 	croak 'No items to shift from the list' if $self->{head}{next} == $self->{tail};
 	my $ret  = $self->{head}{next};
 	$self->{head}{next} = $ret->{next};
-	$ret->{next}{prev} = $$self->{head};
+	$ret->{next}{prev} = $self->{head};
 	return $ret->{item};
 }
 
@@ -159,7 +159,7 @@ List::DoubleLinked - Double Linked Lists for Perl
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
